@@ -6,13 +6,14 @@
 #include <iostream>
 #include <utility>
 
+#include <QAbstractListModel>
 #include <QClipboard>
+#include <QFileInfo>
 #include <QGuiApplication>
 #include <QIcon>
 #include <QLocale>
 #include <QLoggingCategory>
 
-#include <KAboutData>
 #include <KAuth/Action>
 #include <KAuth/ExecuteJob>
 #include <KConfig>
@@ -20,6 +21,8 @@
 #include <KCoreAddons>
 #include <KLocalizedString>
 #include <KOSRelease>
+#include <KPluginFactory>
+#include <KQuickConfigModule>
 #include <KSharedConfig>
 
 #include "CPUEntry.h"
@@ -30,19 +33,15 @@
 #include "OSVersionEntry.h"
 #include "PlasmaEntry.h"
 #include "ServiceRunner.h"
+#include "ThirdPartyEntry.h"
 #include "Version.h"
 
-#include <KAboutData>
-#include <KLocalizedString>
-#include <KPluginFactory>
-#include <KQuickAddons/ConfigModule>
-
 class EntryModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
     enum Role {
-        ModelData = Qt::UserRole,
+        EntryRole = Qt::UserRole,
     };
     Q_ENUM(Role)
 
@@ -61,7 +60,7 @@ public:
         }
 
         switch (static_cast<Role>(intRole)) {
-        case Role::ModelData:
+        case Role::EntryRole:
             return QVariant::fromValue(m_entries.at(index.row()));
         }
 
@@ -76,7 +75,7 @@ public:
         }
 
         roles = QAbstractListModel::roleNames();
-        roles.insert(Role::ModelData, QByteArrayLiteral("modelData"));
+        roles.insert(Role::EntryRole, QByteArrayLiteral("entry"));
         return roles;
     }
 
@@ -93,28 +92,19 @@ private:
 Q_DECLARE_METATYPE(EntryModel *)
 Q_DECLARE_METATYPE(Entry *)
 
-class KCMAboutSystem : public KQuickAddons::ConfigModule
+class KCMAboutSystem : public KQuickConfigModule
 {
     Q_OBJECT
     Q_DISABLE_COPY_MOVE(KCMAboutSystem) // rule of 5
 public:
     explicit KCMAboutSystem(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-        : ConfigModule(parent, data, args)
+        : KQuickConfigModule(parent, data)
         , m_dumpToStdout(args.contains(QStringLiteral("dump")))
     {
         if (m_dumpToStdout) {
             QLoggingCategory::setFilterRules(QStringLiteral("*=false"));
         }
 
-        auto aboutData = new KAboutData;
-        aboutData->setComponentName(QStringLiteral("kcm_about-distro"));
-        aboutData->setDisplayName(i18nc("@title", "About this System"));
-        aboutData->setVersion(QByteArrayLiteral(PROJECT_VERSION));
-        aboutData->setLicense(KAboutLicense::LicenseKey::GPL_V3);
-        aboutData->setCopyrightStatement(i18nc("@info:credit", "Copyright 2012-2020 Harald Sitter"));
-        aboutData->addAuthor(i18nc("@info:credit", "Harald Sitter"), i18nc("@info:credit", "Author"), QStringLiteral("sitter@kde.org"));
-        setAboutData(aboutData);
-
         qmlRegisterType<ServiceRunner>("org.kde.kinfocenter.about_distro.private", 1, 0, "ServiceRunner");
 
         // https://bugs.kde.org/show_bug.cgi?id=366158
@@ -164,6 +154,13 @@ public:
         // Default to not show Build
         const bool showBuild = cg.readEntry("ShowBuild", false);
 
+        // Check if distro want's us to show extra values
+        const QString entryName = QStringLiteral("ExtraSoftwareData");
+        const QStringList entries = cg.readXdgListEntry(entryName, QStringList());
+        for (const auto &script : entries) {
+            m_extraDataEntries.push_back(new ThirdPartyEntry(script));
+        }
+
         // as a product brand is different from Kubuntu.
         const QString distroName = cg.readEntry("Name", os.name());
         const QString osrVersion = cg.readEntry("UseOSReleaseVersion", false) ? os.version() : os.versionId();
@@ -256,6 +253,11 @@ public:
                           new KernelEntry(),
                           new GraphicsPlatformEntry()});
 
+        // Add any extraData entries
+        if (!m_extraDataEntries.empty()) {
+            addEntriesToGrid(m_softwareEntries, m_extraDataEntries);
+        }
+
         // hardware
         addEntriesToGrid(m_hardwareEntries, {new CPUEntry, new MemoryEntry, new GPUEntry});
 
@@ -329,26 +331,28 @@ public:
 private:
     const bool m_dumpToStdout;
     std::vector<const Entry *> m_entries;
+    // Extra data distro wants to show in key/value pairs
+    std::vector<Entry *> m_extraDataEntries;
 
     Q_SIGNAL void changed();
 
-    Q_PROPERTY(EntryModel *softwareEntries MEMBER m_softwareEntries CONSTANT);
+    Q_PROPERTY(EntryModel *softwareEntries MEMBER m_softwareEntries CONSTANT)
     EntryModel *m_softwareEntries = new EntryModel(this);
-    Q_PROPERTY(EntryModel *hardwareEntries MEMBER m_hardwareEntries CONSTANT);
+    Q_PROPERTY(EntryModel *hardwareEntries MEMBER m_hardwareEntries CONSTANT)
     EntryModel *m_hardwareEntries = new EntryModel(this);
 
-    Q_PROPERTY(QString distroLogo MEMBER m_distroLogo NOTIFY changed);
+    Q_PROPERTY(QString distroLogo MEMBER m_distroLogo NOTIFY changed)
     QString m_distroLogo;
-    Q_PROPERTY(QString distroNameVersion MEMBER m_distroNameVersion NOTIFY changed);
+    Q_PROPERTY(QString distroNameVersion MEMBER m_distroNameVersion NOTIFY changed)
     QString m_distroNameVersion;
-    Q_PROPERTY(QString distroVariant MEMBER m_distroVariant NOTIFY changed);
+    Q_PROPERTY(QString distroVariant MEMBER m_distroVariant NOTIFY changed)
     QString m_distroVariant;
-    Q_PROPERTY(QString distroUrl MEMBER m_distroUrl NOTIFY changed);
+    Q_PROPERTY(QString distroUrl MEMBER m_distroUrl NOTIFY changed)
     QString m_distroUrl;
 
-    Q_PROPERTY(bool isEnglish MEMBER m_isEnglish CONSTANT);
+    Q_PROPERTY(bool isEnglish MEMBER m_isEnglish CONSTANT)
     const bool m_isEnglish = QLocale::system().language() == QLocale::English || QLocale::system().language() == QLocale::C;
-    Q_PROPERTY(bool isThisKInfoCenter MEMBER m_isThisKInfoCenter CONSTANT);
+    Q_PROPERTY(bool isThisKInfoCenter MEMBER m_isThisKInfoCenter CONSTANT)
     const bool m_isThisKInfoCenter = qGuiApp->desktopFileName() == QLatin1String("org.kde.kinfocenter");
 };
 
